@@ -174,7 +174,7 @@ def plot_single_def(plot,
                             x_bins=x_bins, 
                             y_bins=y_bins, 
                             units=units, 
-                            estimator=None, 
+                            estimator=estimator, 
                             ci=ci, 
                             n_boot=n_boot, 
                             alpha=alpha, 
